/*
 * Copyright (C) 2002  Pekka Enberg <Pekka.Enberg@cs.helsinki.fi>
 *
 * Distributed under the terms of the GNU General Public License
 * version 2 or later.
 */
#include "xmlindent.h"
#include "version.h"
#include <errno.h>
#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

void version()
{
    printf("%s %s\n", PACKAGE, VERSION);
}

void usage(char * argv[])
{
    printf("%s: [-o <output filename>] [-i <indent level>] [-t] [-c] "
	   "[-h] [-v]\n", argv[0]);
}

int main(int argc, char * argv[])
{
    char * input_filename;
    char output_filename[FILENAME_MAX];
    FILE * input;
    FILE * output;
    int arg_index;
    bool indent_level_explicitly_defined;

    output_filename[0] = '\0';
    indent_level_explicitly_defined = false;

    for (;;) {
	arg_index = getopt(argc, argv, "chi:o:tv");
	if (arg_index == -1) {
	    break;
	}

	switch (arg_index) {
        case 'i':
	    num_indent_chars = atoi(optarg);
	    indent_level_explicitly_defined = true;
	    break;
	case 't':
	    indent_char = '\t';
	    if (!indent_level_explicitly_defined) {
		/* Default indent level for tabs is different.  */
		num_indent_chars = 1;
	    }
	    break;
	case 'o':
	    strcpy(output_filename, optarg);
	    break;
        case 'c':
	    leave_comments_alone = true;
	    break;
	case 'v':
	    version();
	    return EXIT_SUCCESS;
        case 'h':
	    usage(argv);
	    return EXIT_SUCCESS;
        default:
	    usage(argv);
	    return EXIT_FAILURE;
	}
    }

    input_filename = argv[optind];

    if (input_filename != NULL) {
	input = fopen(input_filename, "r");
	if (NULL == input) {
	    error("Could not open '%s': %s.", input_filename,
		  strerror(errno));
	    return EXIT_FAILURE;
	}
    } else {
	input = stdin;
    }

    if (strlen(output_filename) > 0) {
	output = fopen(output_filename, "w");
	if (NULL == output) {
	    error("Could not open '%s': %s.", output_filename,
		  strerror(errno));
	    return EXIT_FAILURE;
	}
    } else {
	output = stdout;
    }
    indent(input, output);
    fclose(output);
    fclose(input);

    return EXIT_SUCCESS;
}
